@@ -179,9 +179,14 @@ class Table:
                 data += " "*pad
             return data
 
-    def __init__(self, data, header=None, colsep="  ", empty=None):
+    FORMATS = ("csv", "json-flat", "json-kv", "json-object", "json-structured", "pretty")
+
+    def __init__(self, data, header=None, colsep=None, empty=None):
         """Create table from data.
 
+        If colsep is not specified, the default column separator is chosen by
+        the output formatter ('  ' for pretty, ',' for csv).
+
         Parameters
         ----------
         data : [[any]]
@@ -189,7 +194,7 @@ class Table:
         header : [any], optional
             Table header. The default is None.
         colsep : str, optional
-            Column separator. The default is "  ".
+            Column separator. The default is None.
         empty : str, optional
             Text to display when table does not contain data. The default is None.
         """
@@ -239,7 +244,8 @@ class Table:
             List of adjusted column widths
         """
         import shutil
-        sepWidth = len(self.colsep)*(self.columns-1)  # total width occupied by separators
+        colsep = self.colsep or "  "
+        sepWidth = len(colsep)*(self.columns-1)  # total width occupied by separators
         contentWidth = sum(self.colwidth)
         termWidth = shutil.get_terminal_size((0, 0)).columns
         if termWidth == 0 or contentWidth+sepWidth <= termWidth:
@@ -270,7 +276,8 @@ class Table:
         line : [Styled]
             List of cells to print
         """
-        cli.print(self.colsep.join(line[i].print(cli, colwidth[i], i == self.columns-1) for i in range(len(line))))
+        colsep = self.colsep or "  "
+        cli.print(colsep.join(line[i].print(cli, colwidth[i], i == self.columns-1) for i in range(len(line))))
 
     def print(self, cli):
         """Print the table.
@@ -302,7 +309,7 @@ class Table:
         if not (self.header or self.data):
             return
         header = [cell.raw for cell in self.header] if self.header else [str(i) for i in range(len(self.data[0]))]
-        writer = csv.DictWriter(cli.stdout, fieldnames=header, delimiter=self.colsep[0] or ",")
+        writer = csv.DictWriter(cli.stdout, fieldnames=header, delimiter=self.colsep or ",")
         if self.header:
             writer.writeheader()
         if not self.data:
@@ -329,6 +336,34 @@ class Table:
                [[cell.raw for cell in row] for row in self.data]
         cli.print(json.dumps(data, default=lambda x: str(x), separators=(",", ":")))
 
+    def jsonObject(self, cli, full):
+        """Create single JSON object with the first column as key
+
+        If full is True, the remaining columns are packed into an object, (like json-structured),
+        otherwise only the second column is used as value and any additional columns are ignored.
+
+        Parameters
+        ----------
+        cli : Cli
+            Cli providing printing functionality
+        full : bool
+            Whether to provide value as object
+        """
+        import json
+
+        def getV(row):
+            return None if len(row) < 2 else row[1].raw
+
+        def getO(row):
+            return {name.raw: value.raw for name, value in zip(self.header[1:], row[1:])}
+
+        if not self.data:
+            cli.print("{}")
+            return
+        mkValue = getO if full else getV
+        data = {str(row[0].raw): mkValue(row) for row in self.data}
+        cli.print(json.dumps(data, default=lambda x: str(x), separators=(",", ":")))
+
     def dump(self, cli, format):
         """Dump table contents in specified format
 
@@ -343,5 +378,7 @@ class Table:
             self.csv(cli)
         elif format in ("json-flat", "json-structured"):
             self.json(cli, format == "json-structured")
+        elif format in ("json-kv", "json-object"):
+            self.jsonObject(cli, format == "json-object")
         else:
             self.print(cli)
