@@ -3,15 +3,15 @@
 # SPDX-FileCopyrightText: 2021 grommunio GmbH
 
 from . import Cli, InvalidUseError
-from .common import proptagCompleter
+from .common import proptagCompleter, Table
 
 from argparse import ArgumentParser
 
 _statusMap = {0: "active", 1: "suspended", 3: "deleted", 4: "shared", 5: "contact"}
 _statusColor = {0: "green", 1: "yellow", 3: "red", 4: "cyan", 5: "blue"}
 _userAttributes = ("ID", "aliases", "changePassword", "chat", "chatAdmin", "domainID", "forward", "homeserverID", "lang",
-                   "ldapID", "maildir", "pop3_imap", "privArchive", "privChat", "privFiles", "privVideo", "publicAddress",
-                   "smtp", "status", "username")
+                   "ldapID", "maildir", "pop3_imap", "privArchive", "privChat", "privFiles", "privVideo", "privWeb", "privDav",
+                   "privEas", "publicAddress", "smtp", "status", "username")
 _deviceStatus = {0: "unknown", 1: "ok", 2: "pending", 4: "requested", 8: "wiped", 16: "pending (account)",
                  32: "requested (account)", 64: "wiped (account)"}
 _deviceStatusStyle = {0: {"attrs": ["dark"]},
@@ -62,6 +62,12 @@ def _dumpUser(cli, user, indent=0):
             privs.append("files")
         if bits & Users.USER_PRIVILEGE_ARCHIVE:
             privs.append("archive")
+        if bits & (Users.USER_PRIVILEGE_WEB | Users.USER_PRIVILEGE_DETAIL1) != Users.USER_PRIVILEGE_DETAIL1:
+            privs.append("web")
+        if bits & (Users.USER_PRIVILEGE_DAV | Users.USER_PRIVILEGE_DETAIL1) != Users.USER_PRIVILEGE_DETAIL1:
+            privs.append("dav")
+        if bits & (Users.USER_PRIVILEGE_EAS | Users.USER_PRIVILEGE_DETAIL1) != Users.USER_PRIVILEGE_DETAIL1:
+            privs.append("eas")
         if len(privs) == 0:
             return ""
         return "("+",".join(privs)+")"
@@ -139,6 +145,64 @@ def _splitData(args):
     return data
 
 
+def _usernamesFromFile(filename, args):
+    import os
+    cli = args._cli
+    ret, user = _getUser(args)
+    if ret:
+        return ret, None, None
+    if not user.maildir:
+        cli.print(cli.col("User has no mailbox", color="yellow"))
+        return 10, None, user
+
+    try:
+        with open(os.path.join(user.maildir, "config", filename), encoding="utf-8") as file:
+            return 0, [line.strip() for line in file if line.strip() != ""], user
+    except FileNotFoundError:
+        return 0, [], user
+    except (PermissionError, TypeError) as err:
+        cli.print(cli.col(str(err), "red"))
+        return 11, None, user
+
+
+def _usernamesToFile(filename, usernames, args):
+    import os
+    from orm.users import Users
+    from tools import formats
+    from tools.config import Config
+    from tools.misc import setDirectoryOwner, setDirectoryPermission
+
+    cli = args._cli
+    ret, user = _getUser(args)
+    if ret:
+        return ret
+    if not user.maildir:
+        cli.print(cli.col("User has no mailbox", color="yellow"))
+        return 10
+
+    if "force" not in args or not args.force:
+        for entry in usernames:
+            if not formats.email.match(entry):
+                cli.print(cli.col(f"'{entry}' is not a valid e-mail address", color="red"))
+                return 11
+            if Users.query.filter(Users.username == entry).count() != 1:
+                cli.print(cli.col(f"'{entry}' is not a known user", color="red"))
+                return 12
+
+    filepath = os.path.join(user.maildir, "config", filename)
+    try:
+        with open(filepath, "w", encoding="utf-8") as file:
+            file.write("\n".join(usernames)+"\n")
+    except (FileNotFoundError, PermissionError) as err:
+        cli.print(cli.col(str(err), "red"))
+        return 13
+    try:
+        setDirectoryOwner(filepath, Config["options"].get("fileUid"), Config["options"].get("fileGid"))
+        setDirectoryPermission(filepath, Config["options"].get("filePermissions"))
+    except Exception as err:
+        cli.print(cli.col(f"Failed to set file permissions: {err}"))
+
+
 def cliUserShow(args):
     cli = args._cli
     cli.require("DB")
@@ -253,6 +317,36 @@ def cliUserDelete(args):
     cli.print("Done.")
 
 
+def cliUserLogin(args):
+    cli = args._cli
+    cli.require("DB")
+    from orm.users import Users
+    user = Users.query.filter(Users.username == args.username).first()
+    if user is None:
+        cli.print(cli.col("User does not exist.", "red"))
+        return 1
+    if user.status != Users.NORMAL:
+        cli.print(cli.col("Login deactivated for {} user.".format(_statusMap.get(user.status, "invalid")), "red"))
+        return 2
+    if user.externID is None and not user.password:
+        cli.print(cli.col("User has no password set.", "red"))
+        return 3
+    from api.security import loginUser, mkCSRF, mkJWT
+    if not args.nopass:
+        if not args.password:
+            args.password = cli.input("Password: ", secret=True)
+        success, msg = loginUser(args.username, args.password)
+        if not success:
+            cli.print(cli.col(f"Login failed: {msg}", "red"))
+            return 4
+    if not args.token:
+        cli.print(cli.col("Login ok.", "green"))
+    else:
+        token = mkJWT({"usr": user.username})
+        csrf = mkCSRF(token)
+        cli.print(cli.col("Token: ", attrs=["bold"])+token+"\n"+cli.col("CSRF: ", attrs=["bold"])+csrf)
+
+
 def _cliUserDevicesDecodeSyncState(args, data, username):
     import base64
     import json
@@ -304,8 +398,6 @@ def _mkWipeStatus(cli, status):
 
 
 def cliUserDevicesList(args):
-    from .common import Table
-
     cli = args._cli
     ret, user = _getUser(args, requireMailbox=True)
     if ret:
@@ -322,7 +414,6 @@ def cliUserDevicesList(args):
 
 
 def cliUserDevicesShow(args):
-    from .common import Table
     cli = args._cli
     ret, user = _getUser(args, requireMailbox=True)
     if ret:
@@ -459,19 +550,61 @@ def cliUserQuery(args):
               "status": lambda v: cli.col(str(v)+"/", attrs=["dark"])+_mkStatus(cli, v)}\
         if args.format == "pretty" else {}
 
-    from .common import Table
     from orm.users import Users
     args.attributes = args.attributes or ("ID", "username", "status")
     query = _mkUserQuery(args)
     query = Users.optimize_query(query, args.attributes)
     users = [user.todict(args.attributes) for user in query]
-    separator = args.separator or ("," if args.format == "csv" else "  ")
     data = [[attrTf.get(attr, lambda x: x)(user.get(attr)) for attr in args.attributes] for user in users]
     header = None if len(args.attributes) <= 1 and args.format == "pretty" else args.attributes
-    table = Table(data, header, separator, cli.col("(no results)", attrs=["dark"]))
+    table = Table(data, header, args.separator, cli.col("(no results)", attrs=["dark"]))
     table.dump(cli, args.format)
 
 
+def cliUserManageFileList(args):
+    cli = args._cli
+    cli.require("DB")
+
+    if "userspec" not in args:
+        raise InvalidUseError()
+    if "action" not in args:
+        args.action = "list"
+
+    filename = args.filename+".txt"
+    ret, usernames, user = _usernamesFromFile(filename, args)
+    if ret:
+        return ret
+
+    if args.action == "add":
+        for username in args.username:
+            if username in usernames:
+                cli.print(cli.col(f"'{username}' already has {args.dispname} permission", "yellow"))
+            else:
+                usernames.append(username)
+        ret = _usernamesToFile(filename, usernames, args)
+    elif args.action == "clear":
+        usernames = ()
+        ret = _usernamesToFile(filename, usernames, args)
+    elif args.action == "remove":
+        args.force = True
+        for username in args.username:
+            if username not in usernames:
+                cli.print(cli.col(f"'{username}' does not have {args.dispname} permission", "yellow"))
+            else:
+                usernames.remove(username)
+        ret = _usernamesToFile(filename, usernames, args)
+
+    if ret:
+        return ret
+    if not usernames:
+        cli.print(cli.col(f"No users have {args.dispname} permission for '{user.username}'", attrs=["dark"]))
+    else:
+        cli.print("User{} with {} permission for '{}':".format("" if len(usernames) == 1 else "s", args.dispname,
+                                                               cli.col(user.username, attrs=["bold"])))
+        for username in usernames:
+            cli.print("  "+username)
+
+
 def _cliUserspecCompleter(prefix, **kwargs):
     from orm.users import Users
     return (user.username for user in Users.query.filter(Users.username.ilike(prefix+"%"))
@@ -529,6 +662,9 @@ def _cliAddUserAttributes(parser: ArgumentParser):
     parser.add_argument("--privChat", type=getBool, metavar="<bool>", help="Whether the user has the chat privilege")
     parser.add_argument("--privFiles", type=getBool, metavar="<bool>", help="Whether the user has the files privilege")
     parser.add_argument("--privVideo", type=getBool, metavar="<bool>", help="Whether the user has the video privilege")
+    parser.add_argument("--privWeb", type=getBool, metavar="<bool>", help="Whether the user has the web privilege")
+    parser.add_argument("--privDav", type=getBool, metavar="<bool>", help="Whether the user has the DAV privilege")
+    parser.add_argument("--privEas", type=getBool, metavar="<bool>", help="Whether the user has the EAS privilege")
     parser.add_argument("--public-address", type=getBool, metavar="<bool>",
                         help="Whether the user has the public address privilege")
     parser.add_argument("--smtp", type=getBool, metavar="<bool>", help="Whether the user has the SMTP privilege")
@@ -559,6 +695,23 @@ def _setupCliUser(subp: ArgumentParser):
         sub.add_argument("device", nargs="*", help="Device ID")
         return sub
 
+    def userListFileParser(parent, name, dispname, handler):
+        ulf = sub.add_parser(name, help=f"Manage {dispname} permission")
+        ulf.set_defaults(_handle=handler, filename=name, dispname=dispname)
+        ulf.add_argument("userspec", help="User ID or name prefix").completer = _cliUserspecCompleter
+        ulfActions = ulf.add_subparsers()
+        ulfAdd = ulfActions.add_parser("add", help=f"Grant {dispname} permissions to user")
+        ulfAdd.set_defaults(action="add")
+        ulfAdd.add_argument("--force", action="store_true", help="Override e-mail user check")
+        ulfAdd.add_argument("username", nargs="+", help="E-Mail address of the user").completer = _cliUserspecCompleter
+        ulfList = ulfActions.add_parser("clear", help=f"Clear {dispname} list")
+        ulfList.set_defaults(action="clear")
+        ulfList = ulfActions.add_parser("list", help=f"List users with {dispname} permission")
+        ulfList.set_defaults(action="list")
+        ulfRemove = ulfActions.add_parser("remove", help=f"Revoke {dispname} permission from user")
+        ulfRemove.set_defaults(action="remove")
+        ulfRemove.add_argument("username", nargs="+", help="E-Mail address of the user").completer = _cliUserspecCompleter
+
     Cli.parser_stub(subp)
     sub = subp.add_subparsers()
     create = sub.add_parser("create",  help="Create user")
@@ -566,6 +719,7 @@ def _setupCliUser(subp: ArgumentParser):
     create.add_argument("--no-defaults", action="store_true", help="Do not apply configured default values")
     create.set_defaults(_handle=cliUserCreate)
     _cliAddUserAttributes(create)
+    userListFileParser(sub, "delegates", "delegate", cliUserManageFileList)
     delete = sub.add_parser("delete", help="Delete user")
     delete.set_defaults(_handle=cliUserDelete)
     delete.add_argument("userspec", help="User ID or name").completer = _cliUserspecCompleter
@@ -588,6 +742,12 @@ def _setupCliUser(subp: ArgumentParser):
     list.add_argument("userspec", nargs="?", help="User ID or name prefix")
     list.add_argument("-f", "--filter", action="append", help="Filter by attribute, e.g. -f ID=42")
     list.add_argument("-s", "--sort", action="append", help="Sort by attribute, e.g. -s username,desc")
+    login = sub.add_parser("login", help="Test user login")
+    login.set_defaults(_handle=cliUserLogin)
+    login.add_argument("username", help="E-Mail address of the user").completer = _cliUserspecCompleter
+    login.add_argument("--nopass", action="store_true", help="Skip password check")
+    login.add_argument("--password", help="User password to check")
+    login.add_argument("--token", action="store_true", help="Generate access and CSFR token on successful login")
     modify = sub.add_parser("modify",  help="Modify user")
     modify.set_defaults(_handle=cliUserModify)
     modify.add_argument("userspec", help="User ID or name prefix").completer = _cliUserspecCompleter
@@ -602,11 +762,12 @@ def _setupCliUser(subp: ArgumentParser):
     query = sub.add_parser("query", help="Query specific user attributes")
     query.set_defaults(_handle=cliUserQuery)
     query.add_argument("-f", "--filter", action="append", help="Filter by attribute, e.g. -f ID=42")
-    query.add_argument("--format", choices=("csv", "json-flat", "json-structured", "pretty"), help="Set output format",
+    query.add_argument("--format", choices=Table.FORMATS, help="Set output format",
                        metavar="FORMAT", default="pretty")
     query.add_argument("--separator", help="Set column separator")
     query.add_argument("-s", "--sort", action="append", help="Sort by attribute, e.g. -s username,desc")
     query.add_argument("attributes", nargs="*", choices=AttrChoice(), help="Attributes to query", metavar="ATTRIBUTE")
+    userListFileParser(sub, "sendas", "send-as", cliUserManageFileList)
     show = sub.add_parser("show", help="Show detailed information about user")
     show.set_defaults(_handle=cliUserShow)
     show.add_argument("userspec", help="User ID or name").completer = _cliUserspecCompleter
